@@ -4,8 +4,9 @@ import sys
 
 import yaml
 
+from livefs_edit import cli
 from livefs_edit.context import EditContext
-from livefs_edit import actions, cli
+from livefs_edit.actions import ACTIONS
 
 
 HELP_TXT = """
@@ -36,6 +37,8 @@ def main(argv):
 
     isopath = argv[0]
     destpath = argv[1]
+    if destpath == '/dev/null':
+        destpath = None
 
     ctxt = EditContext(isopath)
     ctxt.mount_iso()
@@ -46,11 +49,11 @@ def main(argv):
             spec = yaml.load(fp)
         print(spec)
         for action in spec:
-            func = getattr(actions, action.pop('name').replace('-', '_'))
+            func = ACTIONS[action.pop('name')]
             calls.append((func, action))
     else:
         try:
-            calls = cli.parse(actions, argv[2:])
+            calls = cli.parse(ACTIONS, argv[2:])
         except cli.ArgException as e:
             print("parsing actions from command line failed:", e)
             sys.exit(1)
@@ -62,7 +65,8 @@ def main(argv):
                 "with arguments", kw)
             func(ctxt, **kw)
 
-        ctxt.repack_iso(destpath)
+        if destpath is not None:
+            ctxt.repack_iso(destpath)
     finally:
         ctxt.teardown()
 
